@@ -804,8 +804,7 @@ static struct Rectangle<3> rectFromAnim(const Animated* a) {
   return r;
 }
 
-static struct Rectangle<3>
-rectFromBounds(const double lower[3], const double upper[3]) {
+static struct Rectangle<3> rectFromBounds(const double lower[3], const double upper[3]) {
   struct Rectangle<3> r;
   r.tag = NULL;
   for (int i = 0; i < 3; i++) {
@@ -825,8 +824,7 @@ rectFromBounds(const double lower[3], const double upper[3]) {
   return r;
 }
 
-static struct Rectangle<3>
-reverseAxisOrder(const struct Rectangle<3>& s) {
+static struct Rectangle<3> reverseAxisOrder(const struct Rectangle<3>& s) {
   struct Rectangle<3> r;
   r.tag = s.tag;
   for (int i = 0; i < 3; i++) {
@@ -849,7 +847,7 @@ AnimatedCollection::~AnimatedCollection() {
   if (alloc) delete (SingleCycleAllocator*)alloc;
   if (retlist) delete[] retlist;
   if (rect_indices) delete[] rect_indices;
-  if (input) delete[](struct Rectangle<3>*) input;
+  if (input) delete[] (struct Rectangle<3>*)input;
 }
 
 void AnimatedCollection::add(Animated* a) {
@@ -869,7 +867,7 @@ void AnimatedCollection::reserve(int N) {
   for (int i = 0; i < nreserved; i++) { nrect_indices[i] = i; }
   for (int i = 0; i < ntot; i++) { ninput[i] = ((struct Rectangle<3>*)input)[i]; }
 
-  if (input) delete[](struct Rectangle<3>*) input;
+  if (input) delete[] (struct Rectangle<3>*)input;
   if (rect_indices) delete[] rect_indices;
   if (retlist) delete[] retlist;
   input = (void*)ninput;
@@ -880,7 +878,7 @@ void AnimatedCollection::reserve(int N) {
 void AnimatedCollection::clear() {
   ntot = 0;
   nreserved = 0;
-  if (input) delete[](struct Rectangle<3>*) input;
+  if (input) delete[] (struct Rectangle<3>*)input;
   if (rect_indices) delete[] rect_indices;
   if (retlist) delete[] retlist;
   retlist = NULL;
