@@ -52,7 +52,7 @@ class Ball : public Animated {
   virtual ~Ball();
   bool physics(Real time);
 
-  virtual void generateBuffers(const GLuint*, const GLuint*, const GLuint*, bool) const;
+  virtual void updateBuffers(const GLuint*, const GLuint*, const GLuint*, bool);
   virtual void drawBuffers1(const GLuint*) const;
   virtual void drawBuffers2(const GLuint*) const;
 
@@ -97,6 +97,15 @@ class Ball : public Animated {
   double reflectivity;
   int metallic, dontReflectSelf;
 
+  Color bufferBallColor;
+  bool bufferSpike;
+  Color bufferSpikeColor;
+  bool bufferFloat;
+  bool bufferExtraLife;
+  Color bufferExtraLifeColor;
+  bool bufferDizzy;
+  bool bufferJump;
+
   int locateContactPoints(Map*, Cell**, Coord3d*, Coord3d*, ICoord2d*, double*, double*);
   int locateWallBounces(Map*, Coord3d*);
   void generateSandDebris();
