@@ -41,7 +41,7 @@ Bird::Bird(Game &g, Real x, Real y, Real dx, Real dy, Real size, Real speed)
   position[1] = y;
   position[2] = game.map->getHeight(position[0], position[1]) + .5;
   primaryColor = Color(1., 1., 1., 1.);
-  secondaryColor = Color(0.6, 0.8, 0.9, 1.);
+  secondaryColor = Color(SRGBColor(0.6, 0.8, 0.9, 1.));
   animation = 0.0;
   rotation = M_PI - std::atan2(this->dx / lng, this->dy / lng);
   scoreOnDeath = Game::defaultScores[SCORE_BIRD][0];
@@ -54,8 +54,8 @@ Bird::Bird(Game &g, Real x, Real y, Real dx, Real dy, Real size, Real speed)
   boundingBox[1][2] = size;
 }
 
-void Bird::generateBuffers(const GLuint *idxbufs, const GLuint *databufs,
-                           const GLuint *vaolist, bool /*mustUpdate*/) const {
+void Bird::updateBuffers(const GLuint *idxbufs, const GLuint *databufs, const GLuint *vaolist,
+                         bool /*firstCall*/) {
   if (hide > 0.) return;
 
   Color color = primaryColor.toOpaque();
@@ -71,20 +71,11 @@ void Bird::generateBuffers(const GLuint *idxbufs, const GLuint *databufs,
                        {0.f, 0.f},
                        {-0.5f * (GLfloat)size * std::cos((GLfloat)angle), (GLfloat)size},
                        {0.5f * (GLfloat)size * std::cos((GLfloat)angle), (GLfloat)size}};
-  for (int i = 0; i < 4; i++) {
-    GLfloat ox = loc[i][0], oy = loc[i][1];
-    loc[i][0] = -std::cos(rotation) * ox - std::sin(rotation) * oy;
-    loc[i][1] = -std::sin(rotation) * ox + std::cos(rotation) * oy;
-  }
 
-  pos += packObjectVertex(pos, position[0] + loc[0][0], position[1] + loc[0][1], position[2],
-                          1., 1., color, flat);
-  pos += packObjectVertex(pos, position[0] + loc[1][0], position[1] + loc[1][1], position[2],
-                          1., 0., color, flat);
-  pos += packObjectVertex(pos, position[0] + loc[2][0], position[1] + loc[2][1],
-                          position[2] + dz, 0., 1., color, flat);
-  pos += packObjectVertex(pos, position[0] + loc[3][0], position[1] + loc[3][1],
-                          position[2] + dz, 0., 1., color, flat);
+  pos += packObjectVertex(pos, loc[0][0], loc[0][1], 0., 1., 1., color, flat);
+  pos += packObjectVertex(pos, loc[1][0], loc[1][1], 0., 1., 0., color, flat);
+  pos += packObjectVertex(pos, loc[2][0], loc[2][1], dz, 0., 1., color, flat);
+  pos += packObjectVertex(pos, loc[3][0], loc[3][1], dz, 0., 1., color, flat);
 
   ushort idxs[2][3] = {{0, 1, 2}, {0, 3, 1}};
 
@@ -104,8 +95,11 @@ void Bird::drawBuffers2(const GLuint *vaolist) const {
   glDisable(GL_CULL_FACE);
   glEnable(GL_BLEND);
 
-  setActiveProgramAndUniforms(Shader_Object);
-  setObjectUniforms(specularColor, 10.f / 128.f, Lighting_Regular);
+  Matrix4d transform;
+  affineMatrix(transform, identity3, position);
+  rotateZ(-rotation, transform);
+  const UniformLocations *uloc = setActiveProgramAndUniforms(Shader_Object);
+  setObjectUniforms(uloc, transform, specularColor, 10.f / 128.f, Lighting_Regular);
 
   glBindTexture(GL_TEXTURE_2D, textureWings);
 
