@@ -31,7 +31,7 @@ class Bird : public Animated {
  public:
   Bird(Game& g, Real x, Real y, Real dx, Real dy, Real size, Real speed);
 
-  virtual void generateBuffers(const GLuint*, const GLuint*, const GLuint*, bool) const;
+  virtual void updateBuffers(const GLuint*, const GLuint*, const GLuint*, bool);
   virtual void drawBuffers1(const GLuint*) const;
   virtual void drawBuffers2(const GLuint*) const;
 
