@@ -36,8 +36,8 @@ Black::Black(Game& g, Real x, Real y) : Ball(g, Role_Ball) {
   crashTolerance = 7;
 
   /* Set color to black */
-  primaryColor = Color(0.05f, 0.05f, 0.2f, 1.f);
-  specularColor = Color(0.5f, 0.5f, 0.5f, 1.f);
+  primaryColor = Color(SRGBColor(0.05f, 0.05f, 0.2f, 1.f));
+  specularColor = Color(SRGBColor(0.5f, 0.5f, 0.5f, 1.f));
 
   bounceFactor = .8;
   horizon = 5.0;
