@@ -28,7 +28,7 @@ class Cactus : public Animated {
  public:
   Cactus(Game& g, Real x, Real y, Real radius);
 
-  virtual void generateBuffers(const GLuint*, const GLuint*, const GLuint*, bool) const;
+  virtual void updateBuffers(const GLuint*, const GLuint*, const GLuint*, bool);
   virtual void drawBuffers1(const GLuint*) const;
   virtual void drawBuffers2(const GLuint*) const;
 
@@ -38,6 +38,9 @@ class Cactus : public Animated {
   Real base_radius;
   Real killed_time;
   bool killed;
+
+  Color bufferSpikeColor;
+  Color bufferStemColor;
 };
 
 #endif
