@@ -29,7 +29,7 @@ class CalibrateJoystickMode : public GameMode {
   void display();
   void activated();
   void deactivated();
-  void idle(Real);
+  void tick(Real);
   void mouseDown(int state, int x, int y);
   void key(int);
 
