@@ -27,7 +27,7 @@ class Diamond : public Animated {
  public:
   Diamond(Game& g, const Coord3d& position);
 
-  virtual void generateBuffers(const GLuint*, const GLuint*, const GLuint*, bool) const;
+  virtual void updateBuffers(const GLuint*, const GLuint*, const GLuint*, bool);
   virtual void drawBuffers1(const GLuint*) const;
   virtual void drawBuffers2(const GLuint*) const;
 
@@ -37,6 +37,8 @@ class Diamond : public Animated {
  protected:
   Real fade;
   int taken;
+
+  Color bufferColor;
 };
 
 #endif
