@@ -31,7 +31,7 @@ Fountain::Fountain(Game &g, const Coord3d &pos, double randomSpeed, double radiu
       randomSpeed(randomSpeed),
       radius(radius),
       strength(strength) {
-  primaryColor = Color(0.4, 0.4, 0.8, 0.5);
+  primaryColor = Color(SRGBColor(0.4, 0.4, 0.8, 0.5));
   velocity[0] = velocity[1] = 0.0;
   velocity[2] = 0.3;
   position = pos;
@@ -43,8 +43,8 @@ Fountain::Fountain(Game &g, const Coord3d &pos, double randomSpeed, double radiu
   memset(creationTime, 0, sizeof(creationTime));
 }
 
-void Fountain::generateBuffers(const GLuint *idxbufs, const GLuint *databufs,
-                               const GLuint *vaolist, bool /*mustUpdate*/) const {
+void Fountain::updateBuffers(const GLuint *idxbufs, const GLuint *databufs,
+                             const GLuint *vaolist, bool /*mustUpdate*/) {
   if (Settings::settings->gfx_details <= GFX_DETAILS_MINIMALISTIC) return;
 
   int skip = Settings::settings->gfx_details <= GFX_DETAILS_SIMPLE ? 2 : 1;
@@ -111,8 +111,8 @@ void Fountain::drawBuffers2(const GLuint *vaolist) const {
 
   glEnable(GL_BLEND);
   glPointSize(1.5 * screenWidth / 600.);
-  setActiveProgramAndUniforms(Shader_Line);
-  glUniformC(uniformLocations.line_color, primaryColor);
+  const UniformLocations *uloc = setActiveProgramAndUniforms(Shader_Line);
+  glUniformC(uloc->line_color, primaryColor);
 
   glBindVertexArray(vaolist[0]);
   glDrawElements(GL_POINTS, npoints, GL_UNSIGNED_SHORT, (void *)0);
