@@ -28,7 +28,7 @@ class Fountain : public Animated {
   Fountain(Game& g, const Coord3d& position, double randomSpeed, double radius,
            double strength);
 
-  virtual void generateBuffers(const GLuint*, const GLuint*, const GLuint*, bool) const;
+  virtual void updateBuffers(const GLuint*, const GLuint*, const GLuint*, bool);
   virtual void drawBuffers1(const GLuint*) const;
   virtual void drawBuffers2(const GLuint*) const;
 
