@@ -44,6 +44,7 @@ class Player;
 class Weather;
 class EditMode;
 class Gamer;
+class FlagRenderer;
 
 class Game {
  public:
@@ -79,7 +80,6 @@ class Game {
   long gameTicks; /* deterministic */
   Weather *weather;
 
-  static Game *current;
   AnimatedCollection *balls;
 
   char levelName[256];
@@ -110,6 +110,7 @@ class Game {
   } QueuedCall;
   std::vector<QueuedCall> queuedCalls;
   std::vector<GameHook *> newHooks;
+  FlagRenderer *flagRenderer;
 
   static void *runQueuedCalls(void *data);
 
