@@ -26,7 +26,7 @@ class Goal : public Flag {
  public:
   Goal(Game& g, Real x, Real y, int rotate, char* nextLevel);
 
-  virtual void generateBuffers(const GLuint*, const GLuint*, const GLuint*, bool) const;
+  virtual void updateBuffers(const GLuint*, const GLuint*, const GLuint*, bool);
   virtual void drawBuffers1(const GLuint*) const;
   virtual void drawBuffers2(const GLuint*) const;
 
@@ -35,6 +35,8 @@ class Goal : public Flag {
  private:
   char nextLevel[256];
   int rotate;
+
+  Color bufferColor;
 };
 
 #endif
