@@ -47,8 +47,8 @@ class Cell {
    * editMode::pasteRegion */
 
   float velocity[2], heights[5];
-  Color colors[5];
-  Color wallColors[4];
+  SRGBColor colors[5];
+  SRGBColor wallColors[4];
   float sunken;           // used for trampoline effect
   float waterHeights[5];  // absolute height of water in cell, values <= -100.0 is treated as
                           // no water.
@@ -85,17 +85,18 @@ class Chunk {
   Chunk();
   ~Chunk();
   int xm, ym;
-  GLuint wall_vbo[2];
-  GLuint tile_vbo[2];
-  GLuint flag_vbo[2];
-  GLuint flui_vbo[2];
-  GLuint line_vbo[2];
-  GLuint wall_vao, tile_vao, flag_vao, flui_vao, line_vao;
+  GLuint wall_vbo[3];  // vertex data, opaque triangles, alpha triangles
+  GLuint tile_vbo[3];  // vertex data, opaque triangles, alpha triangles
+  GLuint flag_vbo[2];  // vertex data, triangle indices
+  GLuint flui_vbo[2];  // vertex data, triangle indices
+  GLuint line_vbo[2];  // vertex data, line indices
+  GLuint wall_vao, tile_vao, wall_alpha_vao, tile_alpha_vao, flag_vao, flui_vao, line_vao;
   GLfloat maxHeight, minHeight;
   bool is_active, is_visible, is_updated;
   int last_shown;
 };
 
+class ChunkStagingBuffers;
 class Map {
  public:
   explicit Map(char *mapname);
@@ -142,6 +143,7 @@ class Map {
 
  protected:
  private:
+  ChunkStagingBuffers *bufs;
   Cell *cells;
   mutable std::map<std::pair<int, int>, Chunk> chunks;
 };
