@@ -26,8 +26,8 @@ Pipe::Pipe(Game &g, const Coord3d &f, const Coord3d &t, Real r)
     : Animated(g, Role_Pipe, 1), from(f), to(t), radius(r) {
   /* Note that the position attribute of Pipes are not used, use rather the to/from values */
   position = 0.5 * (from + to);
-  primaryColor = Color(0.6, 0.6, 0.6, 1.0);
-  specularColor = Color(0.3, 0.3, 0.3, 1.0);
+  primaryColor = Color(SRGBColor(0.6, 0.6, 0.6, 1.0));
+  specularColor = Color(SRGBColor(0.3, 0.3, 0.3, 1.0));
 
   windBackward = 0.0;
   windForward = 0.0;
@@ -38,9 +38,10 @@ Pipe::Pipe(Game &g, const Coord3d &f, const Coord3d &t, Real r)
   }
 }
 
-void Pipe::generateBuffers(const GLuint *idxbufs, const GLuint *databufs,
-                           const GLuint *vaolist, bool mustUpdate) const {
-  if (!mustUpdate) return;
+void Pipe::updateBuffers(const GLuint *idxbufs, const GLuint *databufs, const GLuint *vaolist,
+                         bool firstCall) {
+  if (!firstCall && primaryColor == bufferColor) { return; }
+  bufferColor = primaryColor;
 
   Coord3d up(0., 0., 0.);
   Coord3d dir = to - from;
@@ -65,12 +66,12 @@ void Pipe::generateBuffers(const GLuint *idxbufs, const GLuint *databufs,
         pos, from[0] + radius * std::sin(angle) * up[0] + radius * std::cos(angle) * right[0],
         from[1] + radius * std::sin(angle) * up[1] + radius * std::cos(angle) * right[1],
         from[2] + radius * std::sin(angle) * up[2] + radius * std::cos(angle) * right[2], 0.,
-        0., primaryColor, norm);
+        0., bufferColor, norm);
     pos += packObjectVertex(
         pos, to[0] + radius * std::sin(angle) * up[0] + radius * std::cos(angle) * right[0],
         to[1] + radius * std::sin(angle) * up[1] + radius * std::cos(angle) * right[1],
         to[2] + radius * std::sin(angle) * up[2] + radius * std::cos(angle) * right[2], 0., 0.,
-        primaryColor, norm);
+        bufferColor, norm);
   }
   for (int i = 0; i < nfacets; i++) {
     int j = (i + 1) % nfacets;
@@ -91,22 +92,22 @@ void Pipe::generateBuffers(const GLuint *idxbufs, const GLuint *databufs,
 }
 
 void Pipe::drawBuffers1(const GLuint *vaolist) const {
-  if (primaryColor.v[3] >= 65535) drawTrunk(vaolist);
+  if (primaryColor.f3() >= 1.f) drawTrunk(vaolist);
 }
 void Pipe::drawBuffers2(const GLuint *vaolist) const {
-  if (activeView.calculating_shadows && primaryColor.v[3] < 45000) return;
-  if (primaryColor.v[3] < 65535) drawTrunk(vaolist);
+  if (activeView.calculating_shadows && primaryColor.f3() < 0.7f) return;
+  if (primaryColor.f3() < 1.f) drawTrunk(vaolist);
 }
 void Pipe::drawTrunk(const GLuint *vaolist) const {
   // Keep off unconditionally since pipe ends show both sides
   glDisable(GL_CULL_FACE);
-  if (primaryColor.v[3] < 65535) {
+  if (primaryColor.f3() < 1.f) {
     glEnable(GL_BLEND);
   } else {
     glDisable(GL_BLEND);
   }
-  setActiveProgramAndUniforms(Shader_Object);
-  setObjectUniforms(specularColor, 10., Lighting_Regular);
+  const UniformLocations *uloc = setActiveProgramAndUniforms(Shader_Object);
+  setObjectUniforms(uloc, identity4, specularColor, 10., Lighting_Regular);
   glBindTexture(GL_TEXTURE_2D, textureBlank);
 
   int nfacets = 32;
