@@ -30,7 +30,7 @@ class Pipe : public Animated {
  public:
   Pipe(Game& g, const Coord3d& from, const Coord3d& to, Real radius);
 
-  virtual void generateBuffers(const GLuint*, const GLuint*, const GLuint*, bool) const;
+  virtual void updateBuffers(const GLuint*, const GLuint*, const GLuint*, bool);
   virtual void drawBuffers1(const GLuint*) const;
   virtual void drawBuffers2(const GLuint*) const;
 
@@ -42,6 +42,7 @@ class Pipe : public Animated {
   Real windForward, windBackward;
 
  private:
+  Color bufferColor;
   void drawTrunk(const GLuint* vaolist) const;
 };
 
