@@ -25,7 +25,7 @@
 PipeConnector::PipeConnector(Game &g, const Coord3d &pos, Real r)
     : Animated(g, Role_PipeConnector, 1), radius(r) {
   position = pos;
-  primaryColor = Color(0.6, 0.6, 0.6, 1.0);
+  primaryColor = Color(SRGBColor(0.6, 0.6, 0.6, 1.0));
 
   boundingBox[0][0] = -radius;
   boundingBox[0][1] = -radius;
@@ -35,20 +35,19 @@ PipeConnector::PipeConnector(Game &g, const Coord3d &pos, Real r)
   boundingBox[1][2] = radius;
 }
 
-void PipeConnector::generateBuffers(const GLuint *idxbufs, const GLuint *databufs,
-                                    const GLuint *vaolist, bool mustUpdate) const {
-  if (!mustUpdate) return;
+void PipeConnector::updateBuffers(const GLuint *idxbufs, const GLuint *databufs,
+                                  const GLuint *vaolist, bool firstCall) {
+  if (!firstCall && primaryColor == bufferColor) { return; }
+  bufferColor = primaryColor;
 
   int ntries = 0;
   int nverts = 0;
-  int detail = 6;
+  int detail = 2;
   countObjectSpherePoints(&ntries, &nverts, detail);
   GLfloat *data = new GLfloat[nverts * 8];
   ushort *idxs = new ushort[ntries * 3];
-  GLfloat pos[3] = {(GLfloat)position[0], (GLfloat)position[1], (GLfloat)position[2]};
-  Matrix3d identity = {{1.f, 0.f, 0.f}, {0.f, 1.f, 0.f}, {0.f, 0.f, 1.f}};
 
-  placeObjectSphere(data, idxs, 0, pos, identity, radius, detail, primaryColor);
+  placeObjectSphere(data, idxs, 0, detail, bufferColor);
 
   glBindVertexArray(vaolist[0]);
   glBindBuffer(GL_ARRAY_BUFFER, databufs[0]);
@@ -60,14 +59,14 @@ void PipeConnector::generateBuffers(const GLuint *idxbufs, const GLuint *databuf
   delete[] idxs;
 }
 void PipeConnector::drawBuffers1(const GLuint *vaolist) const {
-  if (primaryColor.v[3] >= 65535) drawMe(vaolist);
+  if (primaryColor.f3() >= 1.f) drawMe(vaolist);
 }
 void PipeConnector::drawBuffers2(const GLuint *vaolist) const {
-  if (activeView.calculating_shadows && primaryColor.v[3] < 45000) return;
-  if (primaryColor.v[3] < 65535) drawMe(vaolist);
+  if (activeView.calculating_shadows && primaryColor.f3() < 0.7f) return;
+  if (primaryColor.f3() < 1.f) drawMe(vaolist);
 }
 void PipeConnector::drawMe(const GLuint *vaolist) const {
-  if (primaryColor.v[3] < 65535) {
+  if (primaryColor.f3() < 1.f) {
     glEnable(GL_BLEND);
     glDisable(GL_CULL_FACE);
   } else {
@@ -77,11 +76,14 @@ void PipeConnector::drawMe(const GLuint *vaolist) const {
 
   int ntries = 0;
   int nverts = 0;
-  int detail = 6;
+  int detail = 2;
   countObjectSpherePoints(&ntries, &nverts, detail);
 
-  setActiveProgramAndUniforms(Shader_Object);
-  setObjectUniforms(specularColor, 1., Lighting_Regular);
+  Matrix3d scale = {{radius, 0.f, 0.f}, {0.f, radius, 0.f}, {0.f, 0.f, radius}};
+  Matrix4d transform;
+  affineMatrix(transform, scale, position);
+  const UniformLocations *uloc = setActiveProgramAndUniforms(Shader_Object);
+  setObjectUniforms(uloc, transform, specularColor, 1., Lighting_Regular);
   glBindTexture(GL_TEXTURE_2D, textureBlank);
 
   glBindVertexArray(vaolist[0]);
