@@ -27,7 +27,7 @@ class PipeConnector : public Animated {
  public:
   PipeConnector(Game& g, const Coord3d& pos, Real radius);
 
-  virtual void generateBuffers(const GLuint*, const GLuint*, const GLuint*, bool) const;
+  virtual void updateBuffers(const GLuint*, const GLuint*, const GLuint*, bool);
   virtual void drawBuffers1(const GLuint*) const;
   virtual void drawBuffers2(const GLuint*) const;
 
@@ -36,6 +36,7 @@ class PipeConnector : public Animated {
   const Real radius;
 
  private:
+  Color bufferColor;
   void drawMe(const GLuint* vaolist) const;
 };
 
