@@ -23,18 +23,27 @@
 
 #include "ball.h"
 
+struct PlayerControlFrame {
+  double dx, dy;
+  bool jump;      // user requested to jump
+  bool die;       // user requested ball death
+  bool inactive;  // for instance, in between restarts
+};
+
 class Player : public Ball {
  public:
-  Player();
+  Player(Game& g);
   virtual ~Player();
 
   void tick(Real time);
-  void key(int k);
   void die(int);
   void newLevel();
-  void setStartVariables();     /**< Setup all default variables when starting a level */
-  void restart(const Coord3d&); /**< Restart the ball at given position */
+  void setStartVariables();          /**< Setup all default variables when starting a level */
+  void restart(const Coord3d&);      /**< Restart the ball at given position */
+  void handleKey(int key);           /**< Called by main loop on keypress, only if in-game */
+  void handleUserInput(bool active); /**< Called by main loop when there is new data */
   void mouse(int state, int x, int y);
+
   void setHealth(Real);
   virtual bool crash(Real speed);
 
@@ -45,9 +54,7 @@ class Player : public Ball {
   bool playing;
 
  private:
-  void jump();
-
-  int lastJoyX, lastJoyY;
+  PlayerControlFrame control;
 };
 
 #endif
