@@ -77,7 +77,7 @@ void SettingsMode::deactivated() {
     changeScreenResolution();
   }
 }
-void SettingsMode::display() {
+void SettingsMode::display() const {
   glClearColor(0.0, 0.0, 0.0, 0.0);
   glClear(GL_COLOR_BUFFER_BIT);  // | GL_DEPTH_BUFFER_BIT);
 
