@@ -28,7 +28,7 @@ class SideSpike : public Animated {
  public:
   SideSpike(Game& g, const Coord3d& position, Real speed, Real phase, int side);
 
-  virtual void generateBuffers(const GLuint*, const GLuint*, const GLuint*, bool) const;
+  virtual void updateBuffers(const GLuint*, const GLuint*, const GLuint*, bool);
   virtual void drawBuffers1(const GLuint*) const;
   virtual void drawBuffers2(const GLuint*) const;
 
@@ -40,6 +40,10 @@ class SideSpike : public Animated {
  private:
   int soundDone;
   Real offset;
+
+  // properties of the currently submitted buffer
+  Color bufferPrimaryColor;
+  Color bufferSecondaryColor;
 };
 
 #endif
