@@ -29,7 +29,7 @@ class Sign : public Animated {
   virtual ~Sign();
   void mkTexture(const char*);
 
-  virtual void generateBuffers(const GLuint*, const GLuint*, const GLuint*, bool) const;
+  virtual void updateBuffers(const GLuint*, const GLuint*, const GLuint*, bool);
   virtual void drawBuffers1(const GLuint*) const;
   virtual void drawBuffers2(const GLuint*) const;
 
@@ -41,6 +41,7 @@ class Sign : public Animated {
 
   GLuint textimg;
   GLfloat texcoord[4];
+  bool textureChanged;
 };
 
 #endif
