@@ -23,27 +23,47 @@
 
 #include "glHelp.h"
 
-/*  structure for */
-
-typedef struct _glitter {
-  float pos[3];
-  float speed[3];
-  float color[4];
-  float size;
-  float age;
-  struct _glitter *next, *prev;
-} Glitter;
-
 // initialize sparkle module
 Sparkle2D::Sparkle2D() {
   // just be sure that this field is empty
   this->sparkle_first = NULL;
+  nsparkles = 0;
+
+  glGenVertexArrays(1, &vao);
+  glBindVertexArray(vao);
+  glGenBuffers(1, &idxs_buf);
+  glBindBuffer(GL_ELEMENT_ARRAY_BUFFER, idxs_buf);
+  glGenBuffers(1, &data_buf);
+  glBindBuffer(GL_ARRAY_BUFFER, data_buf);
+
+  ushort *idxs = new ushort[6 * MAX_DRAWN_SPARKLES];
+  for (int k = 0; k < MAX_DRAWN_SPARKLES; k++) {
+    idxs[k * 6 + 0] = 4 * k + 0;
+    idxs[k * 6 + 1] = 4 * k + 1;
+    idxs[k * 6 + 2] = 4 * k + 2;
+    idxs[k * 6 + 3] = 4 * k + 1;
+    idxs[k * 6 + 4] = 4 * k + 2;
+    idxs[k * 6 + 5] = 4 * k + 3;
+  }
+  glBindBuffer(GL_ELEMENT_ARRAY_BUFFER, idxs_buf);
+  glBufferData(GL_ELEMENT_ARRAY_BUFFER, MAX_DRAWN_SPARKLES * 6 * sizeof(ushort), idxs,
+               GL_STATIC_DRAW);
+  delete[] idxs;
+
+  glBufferData(GL_ARRAY_BUFFER, MAX_DRAWN_SPARKLES * 8 * 4 * sizeof(GLfloat), NULL,
+               GL_STREAM_DRAW);
+
+  configureUIAttributes();
 }
 
 // destroy
 Sparkle2D::~Sparkle2D() {
   // remove all remaining sparkle
   clear();
+
+  glDeleteBuffers(1, &idxs_buf);
+  glDeleteBuffers(1, &data_buf);
+  glDeleteVertexArrays(1, &vao);
 }
 
 // remove all entries
@@ -66,6 +86,7 @@ void Sparkle2D::remove_sparkle(Sparkle *sparkle) {
   else
     sparkle_first = sparkle->next;
   delete sparkle;
+  nsparkles--;
 }
 
 /*
@@ -78,36 +99,14 @@ Sparkle *Sparkle2D::create_and_insert() {
   tmp->prev = NULL;
   if (sparkle_first != NULL) { sparkle_first->prev = tmp; }
   sparkle_first = tmp;
+  nsparkles++;
   return (tmp);
 }
 
-/*
- * add a new sparkle
- */
-int Sparkle2D::add(float px, float py, float vx, float vy, float ttl, float size, float r,
-                   float g, float b, float a) {
+void Sparkle2D::add(float pos[2], float speed[2], float ttl, float size, float color[4]) {
   Sparkle *sparkle;
 
-  if ((sparkle = create_and_insert()) == NULL) return (0);
-
-  sparkle->pos[0] = px;
-  sparkle->pos[1] = py;
-  sparkle->speed[0] = vx;
-  sparkle->speed[1] = vy;
-  sparkle->color[0] = r;
-  sparkle->color[1] = g;
-  sparkle->color[2] = b;
-  sparkle->color[3] = a;
-  sparkle->size = size;
-  sparkle->ttl = ttl;
-  sparkle->age = 0.;
-
-  return (1);
-}
-int Sparkle2D::add(float pos[2], float speed[2], float ttl, float size, float color[4]) {
-  Sparkle *sparkle;
-
-  if ((sparkle = create_and_insert()) == NULL) return (0);
+  if ((sparkle = create_and_insert()) == NULL) return;
 
   sparkle->pos[0] = pos[0];
   sparkle->pos[1] = pos[1];
@@ -120,60 +119,48 @@ int Sparkle2D::add(float pos[2], float speed[2], float ttl, float size, float co
   sparkle->size = size;
   sparkle->ttl = ttl;
   sparkle->age = 0.;
-
-  return (1);
 }
-int Sparkle2D::add(float pos[2], float speed[2], float ttl, float size) {
-  float col[4] = {1., 0.9, 0.1, 0.9};
-  return add(pos, speed, ttl, size, col);
-}
-int Sparkle2D::add(float pos[2], float speed[2], float ttl) {
-  float col[4] = {1., 0.9, 0.1, 0.9};
-  return add(pos, speed, ttl, 1., col);
-}
-int Sparkle2D::add(float pos[2], float ttl) {
-  float col[4] = {1., 0.9, 0.1, 0.9};
-  float speed[2];
-
-  speed[0] = 2. * frandom() - 1.;
-  speed[1] = 2. * frandom() - 1.;
-  return add(pos, speed, ttl, 1., col);
-}
-int Sparkle2D::add(float pos[2]) {
-  float col[4] = {1., 0.9, 0.1, 0.9};
-  float speed[2];
-
-  speed[0] = 2. * frandom() - 1.;
-  speed[1] = 2. * frandom() - 1.;
-  return add(pos, speed, 0.5 + frandom() * 2., 1., col);
-}
-
 /*
  * draw existing glitters
  */
 void Sparkle2D::draw() {
+  Require2DMode();
   Sparkle *skl = sparkle_first;
-  while (skl != NULL) {
+  for (int i = 0; skl != NULL; i++, skl = skl->next) {
+    if (i >= MAX_DRAWN_SPARKLES) { continue; }
     float age = skl->age;
-    if (age >= 0.) {
-      float tmp;
-      if (age < 0.1) {
-        tmp = 1. - age * 10.;
-      } else
-        tmp = age / skl->ttl;
-      float alpha = 1.0 - tmp;
-      float *clr = skl->color;
+    float tmp;
+    if (age < 0.1) {
+      tmp = 1. - age * 10.;
+    } else
+      tmp = age / skl->ttl;
+    float alpha = 1.0 - tmp;
+    tmp = alpha * alpha;
+    float ex = tmp * skl->size * 0.8;
+    float ey = tmp * skl->size * 1. + (0.02 * age);
 
-      tmp = alpha * alpha;
-      float ex = tmp * skl->size * 0.8;
-      float ey = tmp * skl->size * 1. + (0.02 * age);
-      float *pos = skl->pos;
-
-      draw2DRectangle(pos[0] - ex, pos[1] - ey, 2 * ex, 2 * ey, 0., 0., 1., 1., clr[0], clr[1],
-                      clr[2], clr[3] * alpha, textureGlitter);
+    // 2x vert, 4x color, 2x texco
+    int offsets[4][2] = {{0, 0}, {0, 1}, {1, 0}, {1, 1}};
+    for (int k = 0; k < 4; k++) {
+      int base = i * 8 * 4 + k * 8;
+      data[base + 0] = skl->pos[0] - ex + offsets[k][0] * (2 * ex);
+      data[base + 1] = skl->pos[1] - ey + offsets[k][1] * (2 * ey);
+      data[base + 2] = skl->color[0];
+      data[base + 3] = skl->color[1];
+      data[base + 4] = skl->color[2];
+      data[base + 5] = skl->color[3] * alpha;
+      data[base + 6] = (GLfloat)offsets[k][0];
+      data[base + 7] = (GLfloat)offsets[k][1];
     }
-    skl = skl->next;
   }
+
+  int ndrawn = nsparkles > MAX_DRAWN_SPARKLES ? MAX_DRAWN_SPARKLES : nsparkles;
+
+  glBindVertexArray(vao);
+  glBindBuffer(GL_ARRAY_BUFFER, data_buf);
+  glBufferSubData(GL_ARRAY_BUFFER, 0, ndrawn * 8 * 4 * sizeof(GLfloat), data);
+  glBindTexture(GL_TEXTURE_2D, textureGlitter);
+  glDrawElements(GL_TRIANGLES, 6 * ndrawn, GL_UNSIGNED_SHORT, (void *)0);
 }
 
 /*
