@@ -40,8 +40,8 @@ Splash::Splash(Game& g, Coord3d center, Coord3d velocity, Color color, double st
   }
 }
 
-void Splash::generateBuffers(const GLuint* idxbufs, const GLuint* databufs,
-                             const GLuint* vaolist, bool /*mustUpdate*/) const {
+void Splash::updateBuffers(const GLuint* idxbufs, const GLuint* databufs,
+                           const GLuint* vaolist, bool /*firstCall*/) {
   if (Settings::settings->gfx_details <= GFX_DETAILS_SIMPLE) return;
 
   GLfloat* data = new GLfloat[3 * nDroplets];
@@ -73,8 +73,8 @@ void Splash::drawBuffers2(const GLuint* vaolist) const {
   glEnable(GL_BLEND);
 
   glPointSize(1.5 * screenWidth / 600.);
-  setActiveProgramAndUniforms(Shader_Line);
-  glUniformC(uniformLocations.line_color, primaryColor);
+  const UniformLocations* uloc = setActiveProgramAndUniforms(Shader_Line);
+  glUniformC(uloc->line_color, primaryColor);
 
   glBindVertexArray(vaolist[0]);
   glDrawElements(GL_POINTS, nDroplets, GL_UNSIGNED_SHORT, (void*)0);
