@@ -29,7 +29,7 @@ class CSwitch : public Animated {
   virtual ~CSwitch();
   virtual void releaseCallbacks();
 
-  virtual void generateBuffers(const GLuint*, const GLuint*, const GLuint*, bool) const;
+  virtual void updateBuffers(const GLuint*, const GLuint*, const GLuint*, bool);
   virtual void drawBuffers1(const GLuint*) const;
   virtual void drawBuffers2(const GLuint*) const;
 
@@ -38,6 +38,10 @@ class CSwitch : public Animated {
  private:
   bool is_touched;
   SCM on, off;
+
+  bool bufferIsOn;
+  Color bufferPrimaryColor;
+  Color bufferSecondaryColor;
 };
 
 #endif
