@@ -28,7 +28,7 @@ class Teleport : public Animated {
  public:
   Teleport(Game& g, Real x, Real y, Real dx, Real dy, Real radius);
 
-  virtual void generateBuffers(const GLuint*, const GLuint*, const GLuint*, bool) const;
+  virtual void updateBuffers(const GLuint*, const GLuint*, const GLuint*, bool);
   virtual void drawBuffers1(const GLuint*) const;
   virtual void drawBuffers2(const GLuint*) const;
 
@@ -37,6 +37,8 @@ class Teleport : public Animated {
  protected:
   int x, y, dx, dy;
   Real radius;
+  Color bufferRingColor;
+  Real bufferRadius;
 };
 
 #endif
