@@ -89,11 +89,12 @@ void Weather::tick(Real td, Player *player) {
     }
   }
 
+  GLfloat td_float = (GLfloat)td;
   for (int i = 0; i < max_weather_particles; i++) {
-    Particle *p = &particles[i];
-    p->position[0] += p->velocity[0] * td;
-    p->position[1] += p->velocity[1] * td;
-    p->position[2] += p->velocity[2] * td;
+    Particle &p = particles[i];
+    p.position[0] += p.velocity[0] * td_float;
+    p.position[1] += p.velocity[1] * td_float;
+    p.position[2] += p.velocity[2] * td_float;
   }
 }
 
@@ -149,8 +150,8 @@ void Weather::draw2(Player *player) {
     delete[] data;
 
     // Transfer data
-    setActiveProgramAndUniforms(Shader_Line);
-    glUniform4f(uniformLocations.line_color, 0.3, 0.3, 0.4, 0.7);
+    const UniformLocations *uloc = setActiveProgramAndUniforms(Shader_Line);
+    glUniformC(uloc->line_color, Color(SRGBColor(0.3, 0.3, 0.4, 0.7)));
 
     glBindBuffer(GL_ELEMENT_ARRAY_BUFFER, bufs[1]);
     glVertexAttribPointer(0, 3, GL_FLOAT, GL_FALSE, 0, (void *)0);
@@ -172,7 +173,7 @@ void Weather::draw2(Player *player) {
 
     GLfloat *data = new GLfloat[3 * 8 * nactive];
 
-    Color color(0.8, 0.8, 0.85, 1.);
+    Color color(SRGBColor(0.8, 0.8, 0.85, 1.));
     GLfloat flat[3] = {0.f, 0.f, 0.f};
     GLfloat txc[3][2] = {{0.5f, 0.f}, {0.f, 1.f}, {1.f, 1.f}};
     GLfloat size = 1.3f;
@@ -195,8 +196,8 @@ void Weather::draw2(Player *player) {
     glBufferData(GL_ARRAY_BUFFER, 3 * 8 * nactive * sizeof(GLfloat), data, GL_STATIC_DRAW);
     delete[] data;
 
-    setActiveProgramAndUniforms(Shader_Object);
-    setObjectUniforms(Color(0., 0., 0., 1.), 1., Lighting_None);
+    const UniformLocations *uloc = setActiveProgramAndUniforms(Shader_Object);
+    setObjectUniforms(uloc, identity4, Color(0., 0., 0., 1.), 1., Lighting_None);
     glBindTexture(GL_TEXTURE_2D, textureGlitter);
 
     glBindBuffer(GL_ELEMENT_ARRAY_BUFFER, bufs[1]);
